@@ -1,6 +1,6 @@
 //! Server module
 use std::io;
-use std::net::SocketAddr as StdSocketAddr;
+use std::net::{IpAddr, SocketAddr as StdSocketAddr, ToSocketAddrs};
 use std::pin::Pin;
 use std::task::{Context, Poll};
 
@@ -171,16 +171,15 @@ pub struct TcpListener {
 impl TcpListener {
     /// Bind to socket address.
     #[inline]
-    pub fn bind(addr: impl Into<StdSocketAddr>) -> Self {
-        Self::try_bind(addr).unwrap()
+    pub fn bind(incoming: impl IntoAddrIncoming) -> Self {
+        Self::try_bind(incoming).unwrap()
     }
     /// Try to bind to socket address.
     #[inline]
-    pub fn try_bind(addr: impl Into<StdSocketAddr>) -> Result<Self, hyper::Error> {
-        let mut incoming = AddrIncoming::bind(&addr.into())?;
-        incoming.set_nodelay(true);
-
-        Ok(TcpListener { incoming })
+    pub fn try_bind(incoming: impl IntoAddrIncoming) -> Result<Self, hyper::Error> {
+        Ok(TcpListener {
+            incoming: incoming.into_incoming(),
+        })
     }
 }
 impl Listener for TcpListener {}
@@ -192,3 +191,45 @@ impl Accept for TcpListener {
         Pin::new(&mut self.get_mut().incoming).poll_accept(cx)
     }
 }
+
+/// IntoAddrIncoming
+pub trait IntoAddrIncoming {
+    /// Convert into AddrIncoming
+    fn into_incoming(self) -> AddrIncoming;
+}
+
+impl IntoAddrIncoming for StdSocketAddr {
+    #[inline]
+    fn into_incoming(self) -> AddrIncoming {
+        let mut incoming = AddrIncoming::bind(&self.into()).unwrap();
+        incoming.set_nodelay(true);
+        incoming
+    }
+}
+
+impl IntoAddrIncoming for AddrIncoming {
+    #[inline]
+    fn into_incoming(self) -> AddrIncoming {
+        self
+    }
+}
+
+impl<T: ToSocketAddrs + ?Sized> IntoAddrIncoming for &T {
+    fn into_incoming(self) -> AddrIncoming {
+        for addr in self.to_socket_addrs().expect("failed to create AddrIncoming") {
+            if let Ok(mut incoming) = AddrIncoming::bind(&addr) {
+                incoming.set_nodelay(true);
+                return incoming;
+            }
+        }
+        panic!("failed to create AddrIncoming");
+    }
+}
+
+impl<I: Into<IpAddr>> IntoAddrIncoming for (I, u16) {
+    fn into_incoming(self) -> AddrIncoming {
+        let mut incoming = AddrIncoming::bind(&self.into()).expect("failed to create AddrIncoming");
+        incoming.set_nodelay(true);
+        incoming
+    }
+}
